@@ -3,13 +3,21 @@ from shutil import copy
 
 from django.core.management.base import CommandError, NoArgsCommand
 from django.db.models import get_apps
+from optparse import make_option
 
-from ._utils import file_patt
+from ._utils import file_patt, file_patt_prefixed
 
 
 class Command(NoArgsCommand):
-    
-    def handle(self, *args, **kwargs):
+    can_import_settings = True
+    option_list = NoArgsCommand.option_list + (
+        make_option('--noinput',
+            action='store_false', dest='interactive', default=True,
+            help="Do NOT prompt the user for input of any kind."),
+        )
+
+
+    def handle_noargs(self, **options):
         from django.conf import settings
         
         app_module_paths = []
@@ -33,13 +41,19 @@ class Command(NoArgsCommand):
                         json_fixtures.append((root, os.path.join(root, file)))
             except StopIteration:
                 pass
-        
-        confirm = raw_input("This will overwrite any existing files. Proceed? ")
-        if not confirm.startswith('y'):
-            raise CommandError("Media syncing aborted")
-        
+
+        if options['interactive']:
+            confirm = raw_input("This will overwrite any existing files. Proceed? ")
+            if not confirm.lower().startswith('y'):
+                raise CommandError("Media syncing aborted")
+
+        if getattr(settings, 'FIXTURE_MEDIA_REQUIRE_PREFIX', False):
+            pattern = file_patt_prefixed
+        else:
+            pattern = file_patt
+
         for root, fixture in json_fixtures:
-            file_paths = file_patt.findall(open(fixture).read())
+            file_paths = pattern.findall(open(fixture).read())
             if file_paths:
                 for fp in file_paths:
                     fixture_media = os.path.join(root, 'media')
